Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(296)

Unified Diff: third_party/closure_compiler/externs/system_display.js

Issue 2656433004: - Plumbs through native touch calibration from MD settings to display manager via the system dis… (Closed)
Patch Set: Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/closure_compiler/externs/system_display.js
diff --git a/third_party/closure_compiler/externs/system_display.js b/third_party/closure_compiler/externs/system_display.js
index a6357385e7d06fac4deff277ff6ab1cd08baa862..a37c094e174c75f9e972d40a6992a080ec6a0c97 100644
--- a/third_party/closure_compiler/externs/system_display.js
+++ b/third_party/closure_compiler/externs/system_display.js
@@ -238,35 +238,45 @@ chrome.system.display.overscanCalibrationReset = function(id) {};
chrome.system.display.overscanCalibrationComplete = function(id) {};
/**
* Starts touch calibration for a display. This will show an overlay on the
* screen and initialize the UX for touch calibration. If touch calibration for
* display |id| is in progress this will reset calibration.
* @param {string} id The display's unique identifier.
- * @see https://developer.chrome.com/extensions/system.display#method-touchCalibrationStart
+ * @see https://developer.chrome.com/extensions/system.display#method-showNativeTouchCalibration
*/
-chrome.system.display.touchCalibrationStart = function(id) {};
+chrome.system.display.showNativeTouchCalibration = function(id) {};
/**
- * Sets the touch calibration pairs for a display. These |pairs| would be used
- * to calibrate the touch screen for display |id|. If touch calibration for
- * display |id| is in progress this will do nothing.
+ * Starts custom touch calibration for a display. This should be called when
+ * using a custom UX for collecting calibration data. If another touch
+ * calibration is already in progress this will throw an error.
* @param {string} id The display's unique identifier.
+ * @see https://developer.chrome.com/extensions/system.display#method-startCustomTouchCalibration
+ */
+chrome.system.display.startCustomTouchCalibration = function(id) {};
+
+/**
+ * Sets the touch calibration pairs for a display. These |pairs| would be used
+ * to calibrate the touch screen for display with |id| called in
+ * startCustomTouchCalibration(). Always call |startCustomTouchCalibration|
+ * before calling this method. If another touch calibration is already in
+ * progress this will throw an error.
* @param {!chrome.system.display.TouchCalibrationPairQuad} pairs The pairs of
* point used to calibrate the display.
* @param {!chrome.system.display.Bounds} bounds Bounds of the display when the
* touch calibration was performed. |bounds.left| and |bounds.top|
- * values are no-op.
- * @see https://developer.chrome.com/extensions/system.display#method-touchCalibrationSet
+ * values are ignored.
+ * @see https://developer.chrome.com/extensions/system.display#method-completeCustomTouchCalibration
*/
-chrome.system.display.touchCalibrationSet = function(id, pairs, bounds) {};
+chrome.system.display.completeCustomTouchCalibration = function(pairs, bounds) {};
/**
* Resets the touch calibration for the display and removes the saved
* calibration data.
* @param {string} id The display's unique identifier.
- * @see https://developer.chrome.com/extensions/system.display#method-touchCalibrationReset
+ * @see https://developer.chrome.com/extensions/system.display#method-clearTouchCalibration
*/
-chrome.system.display.touchCalibrationReset = function(id) {};
+chrome.system.display.clearTouchCalibration = function(id) {};
/**
* Fired when anything changes to the display configuration.
« no previous file with comments | « extensions/common/api/system_display.idl ('k') | third_party/closure_compiler/interfaces/system_display_interface.js » ('j') | no next file with comments »
@@ -238,35 +238,45 @@ chrome.system.display.overscanCalibrationReset = function(id) {};
chrome.system.display.overscanCalibrationComplete = function(id) {};
/**
- * Starts touch calibration for a display. This will show an overlay on the
- * screen and initialize the UX for touch calibration. If touch calibration for
- * display |id| is in progress this will reset calibration.
+ * Starts native touch calibration for a display. This will show an overlay on
+ * the screen and initialize the UX for touch calibration. If another native
+ * touch calibration is already in progress this will throw an error.
* @param {string} id The display's unique identifier.

Powered by Google App Engine
This is Rietveld 408576698